Step1: Separate the RNA and ligand from a complex file.

The autodock dlg file contains the results of a number of docked conformations, which can be extracted using following commands[1] in UNIX system:

(1) Extract Dockings from DLG files into PDQT files (my_docking.pdbqt is an assembly of all good docking conformations)

grep '^DOCKED' my_docking.dlg | cut -c9- > my_docking.pdbqt

(2) Converting PDBQT to PDB

cut -c-66 my_docking.pdbqt > my_docking.pdb

(3) Splitting a Multi-Model PDB File into Separate PDB Files

set a=`grep ENDMDL my_docking.pdb | wc -l`
set b=`expr $a - 2`
csplit -k -s -n 3 -f my_docking. mydocking.pdb '/^ENDMDL/+1' '{'$b'}'
foreach f ( mydocking.[0-9][0-9][0-9] )
    mv $f $f.pdb
end

(4) Find the binding energy of each conformation

The DLG file contains the energy of each binding site, we wrote a Perl to extract the information and ranked them. We chose the conformation with the lowest energy and the two resultant pdb files are clover3.pdb and theo.pdb.

Step2: Prepare the protein topology with pdb2gmx.

Use pdb2gmx in Gromacs package:

pdb2gmx -f clover3.pdb -o clover3.gro -water spc

Choose AMBER99SB force field (for protein and nucleic acid).

Step3: Prepare the ligand topology using external tools.

(1) Use antechamber to generate GROMACS topology file

a. Gnerate mol2 file with OpenBable
b. antechamber -i theo.mol2 -fi mol2 -o theo.prep -fo prepi -c resp/-c bcc
c. parmchk -i theo.prep -f prepi -o theo.frcmod
d. In tleap:
   tleap -s -f leaprc.ff99
   mod = loadamberparams theo.frcmod
   loadamberprep theo.prep
   source leaprc.gaff
   RL = loadpdb theo.pdb
   saveamberparm RL file.top file.crd
   quit

Use a Perl program to convert Amber results to Gromacs readable file.

perl amb2gmx.pl --prmtop file --crd theo --outname theo

Thus, we got theo.gro and theo.top.

(2) Build the Complex

(3) Build the Topology

Step4: Solvation

editconf -f complex.gro -o newbox.gro -bt dodecahedron -d 1.0 genbox -cp newbox.gro -cs spc216.gro -p topol.top -o solv.gro

Step5: Adding ions

Use grompp to assemble a .tpr file, with any .mdp file. Here we use a .mdp file for running energy minimization, since they require the fewest parameters.

grompp -f em.mdp -c solv.gro -p topol.top -o ions.tpr

Then, use genion (Our system has a net charge of -157e, so we added 157 Na+):

genion -s ions.tpr -o solv_ions.gro -p topol.top -pname NA -nname CL -pn 157

Step6: Energy Minimization

grompp -f em_real.mdp -c solv_ions.gro -p topol.top -o em.tpr

mdrun -v -deffnm em

Step7: Equilibration

(1) Restraining the ligand

genrestr -f theo.gro -o pose_theo.itp -fc 1000 1000 1000

(2) NVT equilibration

grompp -f npt.mdp -c nvt.gro -t nvt.cpt -p topol.top -n index.ndx -o npt.tpr mdrun -deffnm npt

(3) NPT equilibration

grompp -f npt.mdp -c nvt.gro -t nvt.cpt -p topol.top -n index.ndx -o npt.tpr
mdrun -deffnm npt
Step8: Production MD

grompp -f md_prod.mdp -c npt.gro -t npt.cpt -p topol.top -n index.ndx -o md_prodc.tpr
mdrun -deffnm md_0_1
